@@ -128,14 +128,28 @@ from Technica.Databases.Can import IFrame as IFrame
 from Technica.Databases.Can import IPduInstance as IPduInstance
 from Technica.Databases.Can import ISignalTriggering as ISignalTriggering
 from Technica.Databases.Ethernet import IController as IController
+from Technica.Databases.Ethernet import ICouplingPortDetails as ICouplingPortDetails
+from Technica.Databases.Ethernet import ICouplingPortFifo as ICouplingPortFifo
+from Technica.Databases.Ethernet import IShaper as IShaper
+from Technica.Databases.Ethernet import ICouplingPortScheduler as ICouplingPortScheduler
+from Technica.Databases.Ethernet import SCHEDULER_ALGORITHM as SCHEDULER_ALGORITHM
+from Technica.Databases.Ethernet import ICouplingPortTrafficClassAssignment as ICouplingPortTrafficClassAssignment
 from Technica.Databases.Can import IPduTiming as IPduTiming
 from Technica.Databases.Can import ICyclicTiming as ICyclicTiming
 from Technica.Databases.Can import IEventTiming as IEventTiming
 from Technica.Databases.Can import ISignalTrigger as ISignalTrigger
 from Technica.Databases.Can import ISignalInstanceRef as ISignalInstanceRef
 from Technica.Databases.Can import IEcuPort as IEcuPort
+from Technica.Databases.Ethernet import CONTROL_TYPE as CONTROL_TYPE
 from Technica.Databases.Ethernet import IECUEthernet as IECUEthernet
 from Technica.Databases.Ethernet import CouplingElement as CouplingElement
+from Technica.Databases.Common import IGlobalTimeDomain as IGlobalTimeDomain
+from Technica.Databases.Common import IEthGlobalTimeDomainProps as IEthGlobalTimeDomainProps
+from Technica.Databases.Common import IManagedCouplingPort as IManagedCouplingPort
+from Technica.Databases.Common import GLOBAL_TIME_PORT_ROLE as GLOBAL_TIME_PORT_ROLE
+from Technica.Databases.Common import ETHERNET_GLOBAL_TIME_MESSAGE_FORMAT as ETHERNET_GLOBAL_TIME_MESSAGE_FORMAT
+from Technica.Databases.Common import IGlobalTimeSlave as IGlobalTimeSlave
+from Technica.Databases.Common import GLOBAL_TIME_CRC_VALIDATION as GLOBAL_TIME_CRC_VALIDATION
 from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationSignals import IEcuSignalsNode as IEcuSignalsNode
 from PrimaITestCaseLibrary.Utilities import SignalValue as SignalValue
 from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationBase import ValueChangedArgsMsg as ValueChangedArgsMsg
@@ -147,6 +161,9 @@ from Technica.Databases.Ethernet import INetworkConfiguration as INetworkConfigu
 from Technica.Databases.Lin import IProduct as IProduct
 from Technica.Databases.Lin import ScheduleTable as ScheduleTable
 from Technica.Databases.Lin import ScheduleCommand as ScheduleCommand
+from Technica.Databases.Can import Gateway as Gateway
+from Technica.Databases.Can import GatewayPduMapping as GatewayPduMapping
+from Technica.Databases.Can import GatewaySignalMapping as GatewaySignalMapping
 from Technica.Databases.Common import ITpConfig as ITpConfig
 from Technica.Databases.Common import ICanTpConnection as ICanTpConnection
 from Technica.Databases.Common import AddressingFormat as AddressingFormat
@@ -169,6 +186,7 @@ from PrimaITestCaseLibrary.TestCaseLibrary import ISeriesBuilder as SeriesBuilde
 from PrimaITestCaseLibrary.TestCaseLibrary import ISeries as Series
 from PrimaITestCaseLibrary.TestCaseLibrary import Node as Node
 from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationPdu import IEcuPduNode as EcuNodePDU
+from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationMQTT import IMqttNode as IMqttNode
 from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationCAN import IEcuCanNode as EcuNodeCAN
 from PrimaITestCaseLibrary.NetWorksConfig import IBrspyCanChannelAdapter as ChannelBrspyCAN
 from PrimaITestCaseLibrary.MessageManagment import IMessageCAN as MessageCAN
